@@ -21,12 +21,6 @@
 
 namespace __tsan {
 
-ScopedInRtl::ScopedInRtl() {
-}
-
-ScopedInRtl::~ScopedInRtl() {
-}
-
 uptr GetShadowMemoryConsumption() {
   return 0;
 }
@@ -34,6 +28,13 @@ uptr GetShadowMemoryConsumption() {
 void FlushShadowMemory() {
 }
 
+void WriteMemoryProfile(char *buf, uptr buf_size, uptr nthread, uptr nlive) {
+}
+
+uptr GetRSS() {
+  return 0;
+}
+
 const char *InitializePlatform() {
   return GetEnv(kTsanOptionsEnv);
 }
